﻿using Syncfusion.ListView.XForms;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection.Emit;
using System.Text;

using Xamarin.Forms;

namespace Orientation
{
    public class OrientationCS : ContentPage
    {
        #region Fields

        private ViewModel viewModel;
        SfListView listView;

        #endregion

        #region Constructor

        public OrientationCS()
        {
            Content = InitializeView();
            Title = "SfListView Orientation Sample";
        }

        #endregion

        #region Private Methods

        private Grid InitializeView()
        {
            var grid = new Grid();
            var rowdefinition0 = new RowDefinition { Height = 100 };
            var rowdefinition1 = new RowDefinition { Height = new GridLength(1, GridUnitType.Auto) };
            grid.RowDefinitions.Add(rowdefinition0);
            grid.RowDefinitions.Add(rowdefinition1);

            var stacklayout = new StackLayout() { Orientation = StackOrientation.Vertical, Padding = new Thickness(10, 0, 0, 0) };
            var pizzalabel = new Label() { Text = "Veg Pizza", FontAttributes = FontAttributes.Bold, TextColor = Color.FromHex("#8f0100"), FontSize = 20 };
            var descriptionlabel = new Label() { Text = "Veg pizza prepared with the items that meet vegetarian standards by not including any meat or animal tissue products.",
                                                 TextColor = Color.FromHex("#8f0100"), FontSize = 14 };

            stacklayout.Children.Add(pizzalabel);
            stacklayout.Children.Add(descriptionlabel);

            InitializeListView();

            grid.Children.Add(stacklayout);
            grid.Children.Add(listView, 0, 1);

            return grid;
        }

        private void InitializeListView()
        {
            viewModel = new ViewModel();
            listView = new SfListView()
            {
                ItemsSource = viewModel.PizzaInfo,
                ItemSize = 180,
                HeightRequest = 220,
                SelectionMode = SelectionMode.None,
                Padding = new Thickness(10, 13, 10, -5),
                ItemSpacing = new Thickness(5, 10, 5, 10),
                Orientation = Syncfusion.ListView.XForms.Orientation.Horizontal
            };
            listView.ItemTemplate = new DataTemplate(() => { return CreateItemTemplate(); });
        }

        private Frame CreateItemTemplate()
        {
            var frame = new Frame() { BackgroundColor = Color.FromHex("#ff8e02"), Padding = new Thickness(2), HasShadow = true };
            var grid = new Grid() { RowSpacing = 0, HorizontalOptions = LayoutOptions.Fill, VerticalOptions = LayoutOptions.Fill };

            var rowdefinition0 = new RowDefinition { Height = new GridLength(1, GridUnitType.Star) };
            var rowdefinition1 = new RowDefinition { Height = 20 };
            grid.RowDefinitions.Add(rowdefinition0);
            grid.RowDefinitions.Add(rowdefinition1);

            var image = new Image() { HorizontalOptions = LayoutOptions.FillAndExpand, VerticalOptions = LayoutOptions.FillAndExpand };
            image.SetBinding(Image.SourceProperty, new Binding("PizzaImage"));

            var pizzalabel = new Label()
            {
                LineBreakMode = LineBreakMode.WordWrap,
                HorizontalTextAlignment = TextAlignment.Center,
                VerticalTextAlignment = TextAlignment.Center,
                TextColor = Color.FromHex("#8f0100"),
                FontAttributes = FontAttributes.Bold,
                FontSize = 14
            };
            pizzalabel.SetBinding(Label.TextProperty, new Binding("PizzaName"));

            grid.Children.Add(image);
            grid.Children.Add(pizzalabel, 0, 1);

            frame.Content = grid;
            return frame;
        }

        #endregion
    }
}
